from django.apps import AppConfig


class DjangoUsefulModelsConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'django_handy_models'
    verbose_name = 'Django Handy Models'